function[x,y,T]=EPL_Mask(m,n)

%EXAMPLE 2.6-1: EPL Mask
%Intermediate Heat Transfer with Software Tools
%G.F. Nellis and S.A. Klein
%Cambridge University Press, 2009
%
%INPUTS
%m - number of nodes in x direction
%n - number of nodes in y direction
%
%OUTPUTS
%x - vector of positions in the x direction
%y - vector of positions in the y direction
%T - 2 dimensional array of temperatures
%
W=0.001;            %width of membrane (m)
d=0.75e-6;          %thickness of membrane (m)
q_dot_flux=5000;    %incident energy (W/m^2)
k=150;              %conductivity (W/m-K)
T_st=20;            %mask structure temperature (C)
T_a=20;             %ambient air temperature (C)
h=20;               %heat transfer coefficient (W/m^2-K)

Bi=h*d/k;           %Biot number

%Setup grid
for i=1:m
    x(i,1)=(i-1)*W/(m-1);
end
Dx=W/(m-1);
for j=1:n
    y(j,1)=(j-1)*W/(n-1);
end
Dy=W/(n-1);

A=spalloc(m*n,m*n,5*m*n);   %allocate a sparse matrix for A
%energy balances for internal nodes
for i=2:(m-1)
    for j=2:(n-1)
        A(m*(j-1)+i,m*(j-1)+i)=-2*k*Dy*d/Dx-2*k*Dx*d/Dy-2*h*Dx*Dy;
        A(m*(j-1)+i,m*(j-1)+i-1)=k*Dy*d/Dx;
        A(m*(j-1)+i,m*(j-1)+i+1)=k*Dy*d/Dx;
        A(m*(j-1)+i,m*(j-1-1)+i)=k*Dx*d/Dy;
        A(m*(j-1)+i,m*(j+1-1)+i)=k*Dx*d/Dy;
        b(m*(j-1)+i,1)=-2*h*Dx*Dy*T_a-q_dot_flux*pd_f(x(i,1),y(j,1),W)*Dx*Dy;
    end
end
for j=1:n
   A(m*(j-1)+1,m*(j-1)+1)=1;
   b(m*(j-1)+1,1)=T_st;
   A(m*(j-1)+m,m*(j-1)+m)=1;
   b(m*(j-1)+m,1)=T_st;
end
for i=2:(m-1)
   A(m*(1-1)+i,m*(1-1)+i)=1;
   b(m*(1-1)+i,1)=T_st;
   A(m*(n-1)+i,m*(n-1)+i)=1;
   b(m*(n-1)+i,1)=T_st;
end
X=A\b;
for i=1:m
    for j=1:n
        T(i,j)=X(m*(j-1)+i);
    end
end

function[pd]=pd_f(x,y,W)

pd=0.1+0.5*x*y/W^2;
% d=sqrt((W/2-x)^2+(W/2-y)^2); %compute distance from x,y to center
% if (d<(W/4)) 
%     pd = 0.9;
% else
%     pd = 0.2;
% end


