function[x,y,T]=EPL_Mask2(m,n)

%EXAMPLE 2.6-2: EPL Mask (re-visited)
%Intermediate Heat Transfer with Software Tools
%G.F. Nellis and S.A. Klein
%Cambridge University Press, 2009
%
%INPUTS
%m - number of nodes in x direction
%n - number of nodes in y direction
%
%OUTPUTS
%x - vector of positions in the x direction
%y - vector of positions in the y direction
%T - 2 dimensional array of temperatures
%

%Inputs
W=0.001;            %width of membrane (m)
d=0.75e-6;          %thickness of membrane (m)
q_dot_flux=5000;    %incident energy (W/m^2)
k=150;              %conductivity (W/m-K)
T_st=20;            %mask structure temperature (C)
T_a=20;             %ambient air temperature (C)
h=20;               %heat transfer coefficient (W/m^2-K)

Bi=h*d/k;           %Biot number

%Setup grid
for i=1:m
    x(i,1)=(i-1)*W/(m-1);
end
Dx=W/(m-1)
for j=1:n
    y(j,1)=(j-1)*W/(n-1);
end
Dy=W/(n-1)

T_hat=ones(m,n)*T_st;   %initialize temperature matrix
tol=0.00001;            %stopping criteria - average change in the temperature (K)
err=999;                %initial value of the error - set > tol
while(err>tol)  
    for j=1:n
       T(1,j)=T_st;
       T(m,j)=T_st;
    end
    for i=2:(m-1)
       T(i,1)=T_st;
       T(i,n)=T_st;
    end
    for i=2:(m-1)
        for j=2:(n-1)
            T(i,j)=(2*h*Dx*Dy*T_a+q_dot_flux*pd_f(x(i,1),y(j,1),W)*Dx*Dy+k*Dy*d*(T_hat(i-1,j)+T_hat(i+1,j))/Dx+k*Dx*d*(T_hat(i,j-1)+T_hat(i,j+1))/Dy)/(2*k*Dy*d/Dx+2*k*Dx*d/Dy+2*h*Dx*Dy);
        end
    end
    err=max(max(abs(T-T_hat)));
    T_hat=T;
end
function[pd]=pd_f(x,y,W)

pd=0.1+0.5*x*y/W^2;
% d=sqrt((W/2-x)^2+(W/2-y)^2); %compute distance from x,y to center
% if (d<(W/4)) 
%     pd = 0.9;
% else
%     pd = 0.2;
% end


