%Runs EXAMPLE 3.8-2:  Startup of Magnetic Ablation Process
%Intermediate Heat Transfer with Software Tools
%G.F. Nellis and S.A. Klein
%Cambridge University Press, 2009
%

clear all;

%INPUTS
R_sp=0.001;     %sphere radius (mm)
R_out=10*R_sp;  %outer radius of computational domain (mm)
beta=20000;     %perfusion constant (W/m^3-K)
c_t=3500;       %tissue specific heat capacity (J/kg-K)
rho_t=1000;     %tissue density (kg/m^3)
T_b=310.2;      %body temperature (K)
g_dot_sp=1.0;   %sphere generation (W)

N=51;           %number of nodes spatially
DELTAr=(R_out-R_sp)/(N-1);  %distance between nodes
for i=1:N
    r(i,1)=R_sp+DELTAr*(i-1);   %radial location of each node
end

T_in=T_b*ones(N,1); %initial temperature

tau_sim=300;         %simulation time (s)
OPTIONS=odeset('RelTol',1e-6);
[time,T]=ode45(@(time,T) dTdt_EX3p8d2(time,T,r,g_dot_sp,T_b,c_t,rho_t,beta),[0,tau_sim],T_in,OPTIONS);
T_C=T-273.2;

figure1 = figure('Color',[1 1 1]);
hdlp=plot(time,T_C);
xlabel('Time (s)','FontSize',14,'FontWeight','Bold');
ylabel('Temperature (C)','FontSize',14,'FontWeight','Bold');
set(hdlp,'LineWidth',1.5);
grid on;

figure2 = figure('Color',[1 1 1]);
hdlp2=plot(r,T_C);
xlabel('Radius (m)','FontSize',14,'FontWeight','Bold');
ylabel('Temperature (C)','FontSize',14,'FontWeight','Bold');
set(hdlp2,'LineWidth',1.5);
grid on;

figure3 = figure('Color',[1 1 1]);
[rm,timem]=meshgrid(r,time);
hdlp2=contourf(rm,timem,T_C,10);
colorbar;
xlabel('Radius (m)','FontSize',14,'FontWeight','Bold');
ylabel('Time (s)','FontSize',14,'FontWeight','Bold');
% Create textbox
annotation1 = annotation(...
  figure3,'textbox',...
  'Position',[0.7661 0.9111 0.3149 0.08175],...
  'LineStyle','none',...
  'FontSize',12,...
  'FontWeight','bold',...
  'String',{'Temperature (C)'});
grid on;